==> documentation-library-1.9.0.tgz: package/lib/components/Base.spec.js <==
"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/esm/extends"));

var _jsxRuntime = require("react/jsx-runtime");

var _react = _interopRequireDefault(require("react"));

var _reactDom = _interopRequireDefault(require("react-dom"));

var _Base = _interopRequireWildcard(require("./Base.core"));

var _setupEnvironment = _interopRequireDefault(require("../helpers/setupEnvironment"));

/* global expect */
describe('Base', function () {
  describe('default', function () {
    var Component = _Base["default"];
    var setup = (0, _setupEnvironment["default"])(Component);
    test('should render without crashing', function () {
      // Given
      var props = {}; // When

      var component = /*#__PURE__*/(0, _jsxRuntime.jsx)(Component, (0, _extends2["default"])({}, props)); // Then

      var div = document.createElement('div');

      _reactDom["default"].render(component, div);

      _reactDom["default"].unmountComponentAtNode(div);
    });
    test('should NOT render null', function () {
      // Given
      var props = {}; // When

      var _setup = setup(props),
          container = _setup.container; // Then


      expect(container.innerHTML).toBeString();
      expect(container.innerHTML).not.toHaveLength(0);
    });
    test('should have propTypes and defaultProps ', function () {
      // Given
      var component = Component; // When
      // Then

      expect(component.hasOwnProperty('propTypes')).toBeTruthy();
      expect(component.hasOwnProperty('defaultProps')).toBeTruthy();
    });
    test('should have proper displayName attribute', function () {
      // Given
      // const props = {}
      // When
      var component = Component; // Then

      expect(component.displayName).toBeString();
      expect(component.displayName).not.toHaveLength(0);
      expect(component.displayName).toMatchSnapshot();
    });
    test('should display children only', function () {
      // Given
      var props = {
        children: 'children'
      }; // When

      var _setup2 = setup(props),
          container = _setup2.container,
          getByText = _setup2.getByText;

      var element = getByText(props.children); // Then

      expect(element.localName).toBe('div');
      expect(element.innerHTML).toBeString();
      expect(element.innerHTML).toBe(props.children);
      expect(container).toMatchSnapshot();
    });
    test('should render elementType if an element is given', function () {
      // Given
      var props = {
        elementType: 'element-type',
        children: 'children'
      }; // When

      var _setup3 = setup(props),
          container = _setup3.container,
          getByText = _setup3.getByText;

      var element = getByText(props.children); // Then

      expect(element.localName).toBe(props.elementType);
      expect(element.innerHTML).toBeString();
      expect(element.innerHTML).toBe(props.children);
      expect(container).toMatchSnapshot();
    });
    test('should assign default element in class is given', function () {
      // Given
      var props = {
        className: 'test-classname',
        children: 'children'
      }; // When

      var _setup4 = setup(props),
          container = _setup4.container,
          getByText = _setup4.getByText;

      var element = getByText(props.children); // Then

      expect(element.localName).toBe('span');
      expect(element.innerHTML).toBeString();
      expect(element.innerHTML).toBe(props.children);
      expect(container).toMatchSnapshot();
    });
    test('should assign default elementType if it is deprecated', function () {
      // Given
      var props = {
        deprecated: true,
        children: 'children'
      }; // When

      var _setup5 = setup(props),
          container = _setup5.container,
          getByText = _setup5.getByText;

      var element = getByText(props.children); // Then

      expect(element.localName).toBe('span');
      expect(element.innerHTML).toBeString();
      expect(element.innerHTML).toBe(props.children);
      expect(container).toMatchSnapshot();
    });
    test('should assign default elementType if textTransform is given', function () {
      // Given
      var props = {
        textTransform: _Base.TEXT_TRANSFORM.CAPITALIZE,
        children: 'children'
      }; // When

      var _setup6 = setup(props),
          container = _setup6.container,
          getByText = _setup6.getByText;

      var element = getByText(props.children); // Then

      expect(element.localName).toBe('span');
      expect(element.innerHTML).toBeString();
      expect(element.innerHTML).toBe(props.children);
      expect(container).toMatchSnapshot();
    });
    test('should assign default elementType if fontWeight is given', function () {
      // Given
      var props = {
        fontWeight: _Base.FONT_WEIGHT.BOLD,
        children: 'children'
      }; // When

      var _setup7 = setup(props),
          container = _setup7.container,
          getByText = _setup7.getByText;

      var element = getByText(props.children); // Then

      expect(element.localName).toBe('span');
      expect(element.innerHTML).toBeString();
      expect(element.innerHTML).toBe(props.children);
      expect(container).toMatchSnapshot();
    });
    test('should assign default elementType if textDecoration is given', function () {
      // Given
      var props = {
        textDecoration: _Base.TEXT_DECORATION.UNDERLINE,
        children: 'children'
      }; // When

      var _setup8 = setup(props),
          container = _setup8.container,
          getByText = _setup8.getByText;

      var element = getByText(props.children); // Then

      expect(element.localName).toBe('span');
      expect(element.innerHTML).toBeString();
      expect(element.innerHTML).toBe(props.children);
      expect(container).toMatchSnapshot();
    });
  });
});

==> documentation-library-1.14.0.tgz: package/lib/components/Base.spec.js <==
"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/esm/extends"));

var _jsxRuntime = require("react/jsx-runtime");

var _react = _interopRequireDefault(require("react"));

var _reactDom = _interopRequireDefault(require("react-dom"));

var _Base = _interopRequireWildcard(require("./Base.core"));

var _setupEnvironment = _interopRequireDefault(require("../helpers/setupEnvironment"));

/* global expect */
describe('Base', function () {
  describe('default', function () {
    var Component = _Base["default"];
    var setup = (0, _setupEnvironment["default"])(Component);
    test('should render without crashing', function () {
      // Given
      var props = {}; // When

      var component = /*#__PURE__*/(0, _jsxRuntime.jsx)(Component, (0, _extends2["default"])({}, props)); // Then

      var div = document.createElement('div');

      _reactDom["default"].render(component, div);

      _reactDom["default"].unmountComponentAtNode(div);
    });
    test('should NOT render null', function () {
      // Given
      var props = {}; // When

      var _setup = setup(props),
          container = _setup.container; // Then


      expect(container.innerHTML).toBeString();
      expect(container.innerHTML).not.toHaveLength(0);
    });
    test('should have propTypes and defaultProps ', function () {
      // Given
      var component = Component; // When
      // Then

      expect(component.hasOwnProperty('propTypes')).toBeTruthy();
      expect(component.hasOwnProperty('defaultProps')).toBeTruthy();
    });
    test('should have proper displayName attribute', function () {
      // Given
      // const props = {}
      // When
      var component = Component; // Then

      expect(component.displayName).toBeString();
      expect(component.displayName).not.toHaveLength(0);
      expect(component.displayName).toMatchSnapshot();
    });
    test('should display wrapping default children only', function () {
      // Given
      var props = {
        children: 'children'
      }; // When

      var _setup2 = setup(props),
          container = _setup2.container,
          getByText = _setup2.getByText,
          debug = _setup2.debug;

      var element = getByText(props.children); // Then

      expect(element.localName).toBe('span');
      expect(element.innerHTML).toBeString();
      expect(element.innerHTML).toBe(props.children);
      expect(container).toMatchSnapshot();
    });
    test('should render elementType if an element is given', function () {
      // Given
      var props = {
        elementType: 'element-type',
        children: 'children'
      }; // When

      var _setup3 = setup(props),
          container = _setup3.container,
          getByText = _setup3.getByText;

      var element = getByText(props.children); // Then

      expect(element.localName).toBe(props.elementType);
      expect(element.innerHTML).toBeString();
      expect(element.innerHTML).toBe(props.children);
      expect(container).toMatchSnapshot();
    });
    test('should assign default element in class is given', function () {
      // Given
      var props = {
        className: 'test-classname',
        children: 'children'
      }; // When

      var _setup4 = setup(props),
          container = _setup4.container,
          getByText = _setup4.getByText;

      var element = getByText(props.children); // Then

      expect(element.localName).toBe('span');
      expect(element.innerHTML).toBeString();
      expect(element.innerHTML).toBe(props.children);
      expect(container).toMatchSnapshot();
    });
    test('should assign default elementType if it is deprecated', function () {
      // Given
      var props = {
        deprecated: true,
        children: 'children'
      }; // When

      var _setup5 = setup(props),
          container = _setup5.container,
          getByText = _setup5.getByText;

      var element = getByText(props.children); // Then

      expect(element.localName).toBe('span');
      expect(element.innerHTML).toBeString();
      expect(element.innerHTML).toBe(props.children);
      expect(container).toMatchSnapshot();
    });
    test('should assign default elementType if textTransform is given', function () {
      // Given
      var props = {
        textTransform: _Base.TEXT_TRANSFORM.CAPITALIZE,
        children: 'children'
      }; // When

      var _setup6 = setup(props),
          container = _setup6.container,
          getByText = _setup6.getByText;

      var element = getByText(props.children); // Then

      expect(element.localName).toBe('span');
      expect(element.innerHTML).toBeString();
      expect(element.innerHTML).toBe(props.children);
      expect(container).toMatchSnapshot();
    });
    test('should assign default elementType if fontWeight is given', function () {
      // Given
      var props = {
        fontWeight: _Base.FONT_WEIGHT.BOLD,
        children: 'children'
      }; // When

      var _setup7 = setup(props),
          container = _setup7.container,
          getByText = _setup7.getByText;

      var element = getByText(props.children); // Then

      expect(element.localName).toBe('span');
      expect(element.innerHTML).toBeString();
      expect(element.innerHTML).toBe(props.children);
      expect(container).toMatchSnapshot();
    });
    test('should assign default elementType if textDecoration is given', function () {
      // Given
      var props = {
        textDecoration: _Base.TEXT_DECORATION.UNDERLINE,
        children: 'children'
      }; // When

      var _setup8 = setup(props),
          container = _setup8.container,
          getByText = _setup8.getByText;

      var element = getByText(props.children); // Then

      expect(element.localName).toBe('span');
      expect(element.innerHTML).toBeString();
      expect(element.innerHTML).toBe(props.children);
      expect(container).toMatchSnapshot();
    });
  });
});
